@@ -9,9 +9,9 @@
 #' @param user a character string representing the user name to logging into 'GreenFeed' system
 #' @param pass a character string representing password to logging into 'GreenFeed' system
 #' @param unit numeric or character vector or list representing one or more 'GreenFeed' unit numbers. The order should match with "feedtimes" files
-#' @param gcup a numeric value representing the grams of pellets per cup.
-#' @param start_date a character string representing the start date of the study (format: "dmy")
-#' @param end_date a character string representing the end date of the study (format: "dmy")
+#' @param gcup a numeric value representing the grams of pellets per cup. If dual-hopper you can define multiple grams per unit
+#' @param start_date a character string representing the start date of the study (format: "DD-MM-YY" or "YYYY-MM-DD")
+#' @param end_date a character string representing the end date of the study (format: "DD-MM-YY" or "YYYY-MM-DD")
 #' @param save_dir a character string representing the directory to save the output file
 #' @param rfid_file a character string representing the file with individual IDs. The order should be Visual ID (col1) and RFID (col2)
 #' @param file_path a character string or list representing files(s) with "feedtimes" from 'C-Lock Inc.'
@@ -55,13 +55,13 @@
 
 utils::globalVariables(c(
   "FID", "FeedTime", "CowTag", "Time", "CurrentPeriod", "ndrops",
-  "MassFoodDrop", "Date", "RFID", "pellintakes", "FarmName"
+  "MassFoodDrop", "Date", "RFID", "pellintakes", "FarmName", "FoodType"
 ))
 
 pellin <- function(user = NA, pass = NA, unit, gcup, start_date, end_date,
                    save_dir = tempdir(), rfid_file = NULL, file_path = NULL) {
   message("Please set the 'gcup' parameter based on the 10-drops test.
-           If units have different gram values, define 'gcup' as a vector with an element for each unit.")
+           If units have single or dual-hopper with different 'gcup', define a vector with a value for each unit/hopper.")
 
   # Check Date format
   start_date <- ensure_date_format(start_date)
@@ -113,6 +113,7 @@ pellin <- function(user = NA, pass = NA, unit, gcup, start_date, end_date,
 
   } else {
 
+    file_path <- normalizePath(file_path, mustWork = FALSE) # Convert to absolute path
     ext <- tools::file_ext(file_path)
     if (ext == "csv") {
         # Read CSV file
@@ -124,7 +125,9 @@ pellin <- function(user = NA, pass = NA, unit, gcup, start_date, end_date,
         stop("Unsupported file type. Please provide a CSV, XLS, or XLSX file.")
     }
 
+
     # Detect date format
+    df <- df[!is.na(df$FeedTime),] # Remove NA to match format date
     if (all(grepl("^\\d{4}-\\d{2}-\\d{2}", df$FeedTime))) {
       detected_format <- "%Y-%m-%d %H:%M:%S"
     } else if (all(grepl("^\\d{1,2}/\\d{1,2}/\\d{2}", df$FeedTime))) {
@@ -145,25 +148,6 @@ pellin <- function(user = NA, pass = NA, unit, gcup, start_date, end_date,
         }
       )
 
-    # Read and bind feedtimes data
-    # df <- purrr::map2_dfr(file_path, unit, ~ {
-    #   ext <- tools::file_ext(.x)
-    #
-    #   if (ext == "csv") {
-    #     # Read CSV file
-    #     readr::read_csv(.x, show_col_types = FALSE) %>%
-    #       dplyr::mutate(FID = .y)
-    #   } else if (ext %in% c("xls", "xlsx")) {
-    #     # Read Excel file (both xls and xlsx)
-    #     readxl::read_excel(.x) %>%
-    #       dplyr::mutate(FID = .y)
-    #   } else {
-    #     stop("Unsupported file type. Please provide a CSV, XLS, or XLSX file.")
-    #   }
-    # }) %>%
-    #   dplyr::relocate(FID, .before = FeedTime) %>%
-    #   dplyr::mutate(CowTag = gsub("^0+", "", CowTag))
-
   }
 
   # Process the rfid data
@@ -173,6 +157,7 @@ pellin <- function(user = NA, pass = NA, unit, gcup, start_date, end_date,
   if (!is.null(rfid_file) && is.data.frame(rfid_file) && nrow(rfid_file) > 0) {
     df <- df[df$CowTag %in% rfid_file$RFID, ]
     noGFvisits <- rfid_file$FarmName[!(rfid_file$RFID %in% df$CowTag)]
+
     message("Animal ID not visting GreenFeed: ", paste(noGFvisits, collapse = ", "))
   }
 
@@ -182,29 +167,57 @@ pellin <- function(user = NA, pass = NA, unit, gcup, start_date, end_date,
       ## Convert FeedTime to POSIXct with the correct format
       FeedTime = as.POSIXct(FeedTime, format = "%m/%d/%y %H:%M:%S"),
       Date = as.character(as.Date(FeedTime)),
-      Time = as.numeric(lubridate::period_to_seconds(lubridate::hms(format(FeedTime, "%H:%M:%S"))) / 3600)
+      Time = as.numeric(lubridate::period_to_seconds(lubridate::hms(format(FeedTime, "%H:%M:%S"))) / 3600),
+      FoodType = as.character(FoodType)
     ) %>%
     dplyr::relocate(Date, Time, .before = FID) %>%
     dplyr::select(-FeedTime) %>%
     ## Calculate drops per animal/FID/day
-    dplyr::group_by(CowTag, FID, Date) %>%
+    dplyr::group_by(CowTag, FID, FoodType, Date) %>%
     dplyr::summarise(
       ndrops = dplyr::n(),
       TotalPeriod = max(CurrentPeriod)
     )
 
-  # As units can fit different amount of grams in their cups. We define gcup per unit
+
+  unit <- convert_unit(unit, t=2)
+
+  # Ensure gcup is a vector if it's a single value
+  if (length(gcup) == 1 && length(unit) == 1) {
+    # Single unit, single gcup
+    gcup <- rep(gcup, 1)  # No repetition needed
+    message("Single Unit, Single FoodType")
+  } else if (length(gcup) == 1 && length(unit) == 2) {
+    # Two units, single gcup
+    gcup <- rep(gcup, length(unit))  # Repeat gcup for both units
+    message("Two Units, Single FoodType")
+  } else if (length(gcup) == 1 && length(unit) > 2) {
+    # More than two units, single gcup
+    gcup <- rep(gcup, length(unit))  # Repeat gcup for each unit
+    message("Multiple Units, Single FoodType")
+  } else if (length(gcup) == length(unit)) {
+    # Each unit gets one gcup (one food type per unit)
+    message("Each Unit Drops One FoodType")
+  } else if (length(gcup) == length(unit) * 2) {
+    # Each unit gets two gcup values (two food types per unit)
+    message("Each Unit Drops Two FoodType")
+  } else {
+    stop("The length of gcup must be consistent with the number of units.")
+  }
+
+  # Now create the data frame with multiple food types per unit
   grams_df <- data.frame(
-    FID = convert_unit(unit,2), #Ensure character format
-    gcup = as.numeric(gcup)           #Ensure numeric format
+    FID = rep(unit, each = length(gcup) / length(unit)), # Ensure character format
+    FoodType = as.character(rep(seq_len(length(gcup) / length(unit)), times = length(unit))), # Assign food type sequentially
+    gcup = as.numeric(gcup) # Ensure numeric format
   )
 
   # Calculate MassFoodDrop by number of cup drops times grams per cup
   pellintakes <- number_drops %>%
-    dplyr::left_join(grams_df, by = "FID") %>%
+    dplyr::left_join(grams_df, by = c("FID", "FoodType")) %>%
     dplyr::mutate(MassFoodDrop = ndrops * gcup) %>%
     ## Create a table with alfalfa pellets (AP) intakes in kg
-    dplyr::group_by(CowTag, Date) %>%
+    dplyr::group_by(CowTag, FoodType, Date) %>%
     ## MassFoodDrop divided by 1000 to transform g in kg
     dplyr::summarise(MassFoodDrop = sum(MassFoodDrop) / 1000)
 
@@ -216,17 +229,22 @@ pellin <- function(user = NA, pass = NA, unit, gcup, start_date, end_date,
     CowTag = unique(pellintakes$CowTag)
   )
 
-  ## Merge pellet intakes with our 'grid' and set MassFoodDrop to 0 for days without visits
-  pellintakes <- merge(pellintakes, grid_visits, all = TRUE)
-  pellintakes$MassFoodDrop[is.na(pellintakes$MassFoodDrop)] <- 0
+  ## Merge pellet intakes with our 'grid' and set to 0 the NA values
+  pellintakes <- merge(pellintakes, grid_visits, all = TRUE) %>%
+    dplyr::mutate(
+      MassFoodDrop = ifelse(is.na(MassFoodDrop), 0, MassFoodDrop),
+      FoodType = ifelse(is.na(FoodType), 0, FoodType)
+    ) %>%
+    dplyr::relocate(FoodType, .after = MassFoodDrop)
+
 
   ## Adding the farm name (if rfid_file is provided) to the pellet intakes file
   if (!is.null(rfid_file) && is.data.frame(rfid_file) && nrow(rfid_file) > 0) {
     pellintakes <- rfid_file[, 1:2] %>%
       dplyr::inner_join(pellintakes, by = c("RFID" = "CowTag"))
-    names(pellintakes) <- c("FarmName", "RFID", "Date", "PIntake_kg")
+    names(pellintakes) <- c("FarmName", "RFID", "Date", "PIntake_kg", "FoodType")
   } else {
-    names(pellintakes) <- c("RFID", "Date", "PIntake_kg")
+    names(pellintakes) <- c("RFID", "Date", "PIntake_kg", "FoodType")
   }
 
 
@@ -242,18 +260,13 @@ pellin <- function(user = NA, pass = NA, unit, gcup, start_date, end_date,
   # Add missing dates for each RFID (and FarmName if available)
   if (!is.null(rfid_file) && is.data.frame(rfid_file) && nrow(rfid_file) > 0) {
     df <- df %>% tidyr::complete(Date = all_dates, tidyr::nesting(FarmName, RFID))
-  } else {
-    df <- df %>% tidyr::complete(Date = all_dates, tidyr::nesting(RFID))
-  }
 
-
-  # Include in the pellet intakes file animals without visits
-  if (!is.null(rfid_file) && is.data.frame(rfid_file) && nrow(rfid_file) > 0) {
     ## Create all possible combinations of date and RFID for animals without visits
     grid_missing <- expand.grid(
       Date = unique(df$Date),
       RFID = rfid_file$RFID[rfid_file$FarmName %in% noGFvisits],
-      PIntake_kg = 0
+      PIntake_kg = 0,
+      FoodType = 0
     )
 
     ## Add the corresponding FarmName for each RFID
@@ -261,6 +274,18 @@ pellin <- function(user = NA, pass = NA, unit, gcup, start_date, end_date,
 
     ## Combine data with cows visiting and not visiting
     df <- rbind(df, grid_missing)
+
+  } else {
+    df <- df %>% tidyr::complete(Date = all_dates, tidyr::nesting(RFID))
+  }
+
+
+  # Ensure save_dir is an absolute path
+  save_dir <- normalizePath(save_dir, mustWork = FALSE)
+
+  # Check if the directory exists, and create it if necessary
+  if (!dir.exists(save_dir)) {
+    dir.create(save_dir, recursive = TRUE)
   }
 
   # Save pellet intakes as a csv file with kg of pellets for the period requested
